@@ -729,7 +729,7 @@ class FeedingIt:
 
         self.buttons = {}
         list = self.listing.getListOfFeeds()[:]
-        list.reverse()
+        #list.reverse()
         for key in list:
             #button = gtk.Button(item)
             button = hildon.Button(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT,
@@ -747,10 +747,14 @@ class FeedingIt:
         self.window.show_all()
 
     def refreshList(self):
-        for key in self.buttons.keys():
-            button = self.buttons[key]
-            button.set_text(self.listing.getFeedTitle(key), self.listing.getFeedUpdateTime(key) + " / " 
+        for key in self.listing.getListOfFeeds():
+            if self.buttons.has_key(key):
+                button = self.buttons[key]
+                button.set_text(self.listing.getFeedTitle(key), self.listing.getFeedUpdateTime(key) + " / " 
                             + str(self.listing.getFeedNumberOfUnreadItems(key)) + " Unread Items")
+            else:
+                self.displayListing()
+                break
 
     def buttonFeedClicked(widget, button, self, window, key):
         disp = DisplayFeed(self.listing, self.listing.getFeed(key), self.listing.getFeedTitle(key), key, self.config)
